def is_even(number: int) -> bool:
    """Return True if the number is even."""
    return number % 2 == 0


def is_odd(number: int) -> bool:
    """Return True if the number is odd."""
    return number % 2 != 0
